@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploaderConfig.cpp 2756 2007-12-11 10:57:59Z svn $
+ * $Id: UploaderConfig.cpp 2768 2007-12-16 13:03:37Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -46,10 +46,14 @@
 #include "Message.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: UploaderConfig.cpp 2756 2007-12-11 10:57:59Z svn $");
+SOURCE_INFO_ADD("$Id: UploaderConfig.cpp 2768 2007-12-16 13:03:37Z svn $");
 
 #define PARAM_PREFIX "Uploader"
 
+const UploaderConfig::item_t UploaderConfig::PATH               = {
+    PARAM_PREFIX "Path",
+    "Path",
+};
 const UploaderConfig::item_t UploaderConfig::BASE_URL           = {
     PARAM_PREFIX "BaseUrl",
     "Base URL",
@@ -120,7 +124,8 @@ const UploaderConfig::item_t UploaderConfig::ERROR_VIEW_TEMPLATE = {
  * public メソッド
  *****************************************************************************/
 UploaderConfig::UploaderConfig(apr_pool_t *pool)
-  : base_url(""),
+  : path(""),
+    base_url(""),
     data_dir_path(""),
     file_dir_path(""),
     temp_dir_path(""),
